@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2015 Red Hat, Inc. <http://www.redhat.com/>
@@ -10,7 +9,10 @@
 # cases as published by the Free Software Foundation.
 
 import os
-import ConfigParser
+try:
+    from configparser import ConfigParser
+except ImportError:
+    import ConfigParser
 
 config = ConfigParser.ConfigParser()
 config.read(os.path.join(os.path.dirname(os.path.abspath(__file__)),
